@@ -1,10 +1,10 @@
 # Functions for collecting general system info
 
-# collect_system_info([manual-refesh-no-cache])
+# collect_system_info([manual-refresh-no-cache], [from-config-check])
 # Returns a hash reference containing system information
 sub collect_system_info
 {
-my ($manual) = @_;
+my ($manual, $confchk) = @_;
 &foreign_require("system-status");
 local $info = &system_status::get_collected_info($manual);
 
@@ -174,7 +174,7 @@ foreach my $f ("virtualmin", @features) {
 	}
 foreach my $f (@plugins) {
 	if (&plugin_defined($f, "feature_sysinfo")) {
-		my @rs = &plugin_call($f, "feature_sysinfo", $manual);
+		my @rs = &plugin_call($f, "feature_sysinfo", $manual, $confchk);
 		push(@progs, @rs) if (@rs);
 		}
 	}
@@ -194,17 +194,20 @@ foreach my $d (@doms_all) {
 			delete($d->{'ssl_cert_expiry'});
 			&save_domain($d);
 			}
-		next;
 		}
-	my @st = stat($d->{'ssl_cert'});
-	next if (!@st);		# Should never happen
-	next if ($d->{'ssl_cert_expiry_cache'} == $st[9]);
-	my $info = &cert_info($d);
-	next if (!$info);
-	$d->{'ssl_cert_expiry_cache'} = $st[9];
-	my $notafter = &parse_notafter_date($info->{'notafter'});
-	$d->{'ssl_cert_expiry'} = $notafter;
-	&save_domain($d);
+	else {
+		# Updated cached expiry date, if cert file has changed
+		my @st = stat($d->{'ssl_cert'});
+		my $info;
+		if (@st && $d->{'ssl_cert_expiry_cache'} != $st[9] &&
+		    ($info = &cert_info($d))) {
+			$d->{'ssl_cert_expiry_cache'} = $st[9];
+			my $notafter = &parse_notafter_date(
+					$info->{'notafter'});
+			$d->{'ssl_cert_expiry'} = $notafter;
+			&save_domain($d);
+			}
+		}
 	&unlock_domain($d);
 	}
 
