@@ -26,7 +26,7 @@ return "A semantic personal publishing platform with a focus on aesthetics, web
 # script_wordpress_versions()
 sub script_wordpress_versions
 {
-return ( "6.8.2", "5.9.9", "4.9.25", "3.9.40" );
+return ( "6.8.3", "5.9.9", "4.9.25", "3.9.40" );
 }
 
 sub script_wordpress_category
@@ -73,7 +73,7 @@ return ( "mysql" );
 
 sub script_wordpress_release
 {
-return 12; # zip extension has to be installed
+return 13; # single quotes aren't the only valid syntax
 }
 
 sub script_wordpress_php_fullver
@@ -571,7 +571,7 @@ foreach my $wpconfig (@$files) {
 	my $lref = &read_file_lines($wpconfig, 1);
 	my %conf;
 	foreach my $l (@$lref) {
-		if ($l =~ /define\(\s*'(\S+)'\s*,\s*'(.*)'/) {
+		if ($l =~ /define\(\s*['"](\S+)['"]\s*,\s*['"](.*)['"]/) {
 			$conf{$1} = $2;
 			}
 		}
